From: guido <guido@0785d39b-7218-0410-832d-ea1e28bc413d>
Date: Sat, 18 Dec 2004 16:54:12 +0000 (+0000)
Subject: QGaussN removed
X-Git-Url: https://gitweb.dealii.org/cgi-bin/gitweb.cgi?a=commitdiff_plain;h=2e73ff36265784b835129834c49390345e972198;p=dealii-svn.git

QGaussN removed


git-svn-id: https://svn.dealii.org/trunk@9819 0785d39b-7218-0410-832d-ea1e28bc413d
---

diff --git a/deal.II/examples/step-11/step-11.cc b/deal.II/examples/step-11/step-11.cc
index 308228b075..02f1388810 100644
--- a/deal.II/examples/step-11/step-11.cc
+++ b/deal.II/examples/step-11/step-11.cc
@@ -4,7 +4,7 @@
 /*    $Id$       */
 /*    Version: $Name$                                          */
 /*                                                                */
-/*    Copyright (C) 2001, 2002, 2003 by the deal.II authors */
+/*    Copyright (C) 2001, 2002, 2003, 2004 by the deal.II authors */
 /*                                                                */
 /*    This file is subject to QPL and may not be  distributed     */
 /*    without copyright and license information. Please refer     */
@@ -450,22 +450,6 @@ void LaplaceProblem<dim>::assemble_and_solve ()
 				   // formula above computing
 				   // ``gauss_degree''.
 				   //
-				   // Note also, that we have used a
-				   // class called ``QGauss''. By now,
-				   // we have only used ``QGauss4'',
-				   // or the like, which implement a
-				   // Gauss quadrature rule of fixed
-				   // order. The ``QGauss'' class is
-				   // more general, taking a parameter
-				   // which indicates of which degree
-				   // it shall be; for small degrees,
-				   // the object then parallels
-				   // objects of type ``QGaussR'' with
-				   // fixed R, but it also provides
-				   // quadrature rules of higher
-				   // degree which are no longer
-				   // hard-coded in the library.
-
 				   // Since the generation of the body
 				   // force contributions to the right
 				   // hand side vector was so simple,
diff --git a/deal.II/examples/step-12/step-12.cc b/deal.II/examples/step-12/step-12.cc
index 425c02cdc1..2db49857ea 100644
--- a/deal.II/examples/step-12/step-12.cc
+++ b/deal.II/examples/step-12/step-12.cc
@@ -589,8 +589,8 @@ class DGMethod
 				     // formulae for the cell and the
 				     // face terms of the
 				     // discretization.
-    const QGauss4<dim>   quadrature;
-    const QGauss4<dim-1> face_quadrature;
+    const QGauss<dim>   quadrature;
+    const QGauss<dim-1> face_quadrature;
     
 				     // And there are two solution
 				     // vectors, that store the
@@ -620,8 +620,8 @@ DGMethod<dim>::DGMethod ()
 						 // different degrees.
                 fe (1),
 		dof_handler (triangulation),
-		quadrature (),
-		face_quadrature (),
+		quadrature (4),
+		face_quadrature (4),
 		dg ()
 {}
 
diff --git a/deal.II/examples/step-13/step-13.cc b/deal.II/examples/step-13/step-13.cc
index 3ad079e200..1a8fdf2697 100644
--- a/deal.II/examples/step-13/step-13.cc
+++ b/deal.II/examples/step-13/step-13.cc
@@ -1766,7 +1766,7 @@ namespace LaplaceSolver
   {
     Vector<float> estimated_error_per_cell (this->triangulation->n_active_cells());
     KellyErrorEstimator<dim>::estimate (this->dof_handler,
-					QGauss3<dim-1>(),
+					QGauss<dim-1>(3),
 					typename FunctionMap<dim>::type(),
 					this->solution,
 					estimated_error_per_cell);
@@ -2005,7 +2005,7 @@ void solve_problem (const std::string &solver_name)
   GridGenerator::hyper_cube (triangulation, -1, 1);
   triangulation.refine_global (2);
   const FE_Q<dim>          fe(1);
-  const QGauss4<dim>       quadrature;
+  const QGauss<dim>       quadrature(4);
   const RightHandSide<dim> rhs_function;
   const Solution<dim>      boundary_values;
 
diff --git a/deal.II/examples/step-14/step-14.cc b/deal.II/examples/step-14/step-14.cc
index c06942c9d6..8849e93501 100644
--- a/deal.II/examples/step-14/step-14.cc
+++ b/deal.II/examples/step-14/step-14.cc
@@ -1078,7 +1078,7 @@ namespace LaplaceSolver
   {
     Vector<float> estimated_error_per_cell (this->triangulation->n_active_cells());
     KellyErrorEstimator<dim>::estimate (this->dof_handler,
-					QGauss3<dim-1>(),
+					QGauss<dim-1>(3),
 					typename FunctionMap<dim>::type(),
 					this->solution,
 					estimated_error_per_cell);
@@ -2051,7 +2051,7 @@ namespace DualFunctional
 				     // formula, have abbreviations
 				     // for the number of quadrature
 				     // points and shape functions...
-    QGauss4<dim> quadrature;
+    QGauss<dim> quadrature(4);
     FEValues<dim>  fe_values (dof_handler.get_fe(), quadrature,
 			      update_gradients |
 			      update_q_points  |
diff --git a/deal.II/examples/step-15/step-15.cc b/deal.II/examples/step-15/step-15.cc
index 74dc3d7aca..85a2ecbc05 100644
--- a/deal.II/examples/step-15/step-15.cc
+++ b/deal.II/examples/step-15/step-15.cc
@@ -411,7 +411,7 @@ void MinimizationProblem<dim>::assemble_step ()
                                    // is a polynomial of sixth order. Thus,
                                    // the appropriate quadrature formula is
                                    // the one we have chosen here.
-  QGauss4<dim>  quadrature_formula;
+  QGauss<dim>  quadrature_formula(4);
   FEValues<dim> fe_values (fe, quadrature_formula, 
 			   UpdateFlags(update_values    |
 				       update_gradients |
@@ -1265,7 +1265,7 @@ MinimizationProblem<dim>::energy (const DoFHandler<dim> &dof_handler,
                                    // that the integrand is a polynomial of
                                    // degree six, so a 4-point Gauss formula
                                    // is appropriate:
-  QGauss4<dim>  quadrature_formula;
+  QGauss<dim>  quadrature_formula(4);
   FEValues<dim> fe_values (dof_handler.get_fe(), quadrature_formula, 
 			   UpdateFlags(update_values    |
 				       update_gradients |
diff --git a/deal.II/examples/step-16/step-16.cc b/deal.II/examples/step-16/step-16.cc
index c701b3c890..fdfbde66b0 100644
--- a/deal.II/examples/step-16/step-16.cc
+++ b/deal.II/examples/step-16/step-16.cc
@@ -194,7 +194,7 @@ void LaplaceProblem<dim>::setup_system ()
 template <int dim>
 void LaplaceProblem<dim>::assemble_system () 
 {  
-  QGauss2<dim>  quadrature_formula;
+  QGauss<dim>  quadrature_formula(2);
 
   FEValues<dim> fe_values (fe, quadrature_formula, 
 			   UpdateFlags(update_values    |
@@ -301,7 +301,7 @@ void LaplaceProblem<dim>::assemble_system ()
 template <int dim>
 void LaplaceProblem<dim>::assemble_multigrid () 
 {  
-  QGauss2<dim>  quadrature_formula;
+  QGauss<dim>  quadrature_formula(2);
 
   FEValues<dim> fe_values (fe, quadrature_formula, 
 			   UpdateFlags(update_values |
diff --git a/deal.II/examples/step-17/step-17.cc b/deal.II/examples/step-17/step-17.cc
index 4043f2e8eb..b46231fd77 100644
--- a/deal.II/examples/step-17/step-17.cc
+++ b/deal.II/examples/step-17/step-17.cc
@@ -593,7 +593,7 @@ void ElasticProblem<dim>::assemble_system ()
                                    // from step-8. Note that we still use the
                                    // deal.II full matrix and vector types for
                                    // the local systems.
-  QGauss2<dim>  quadrature_formula;
+  QGauss<dim>  quadrature_formula(2);
   FEValues<dim> fe_values (fe, quadrature_formula, 
 			   UpdateFlags(update_values    |
 				       update_gradients |
@@ -1157,7 +1157,7 @@ void ElasticProblem<dim>::refine_grid ()
                                    // (i.e. the one indicating the subdomain):
   Vector<float> local_error_per_cell (triangulation.n_active_cells());
   KellyErrorEstimator<dim>::estimate (dof_handler,
-                                      QGauss2<dim-1>(),
+                                      QGauss<dim-1>(2),
                                       typename FunctionMap<dim>::type(),
                                       localized_solution,
                                       local_error_per_cell,
diff --git a/deal.II/examples/step-3/step-3.cc b/deal.II/examples/step-3/step-3.cc
index fe9469c87e..aa83fc01dd 100644
--- a/deal.II/examples/step-3/step-3.cc
+++ b/deal.II/examples/step-3/step-3.cc
@@ -344,7 +344,7 @@ void LaplaceProblem::assemble_system ()
 				   // the matrix entries are quadratic
 				   // (in 1D), this is sufficient. The
 				   // same holds for 2D.
-  QGauss2<2>  quadrature_formula;
+  QGauss<2>  quadrature_formula(2);
 				   // And we initialize the object
 				   // which we have briefly talked
 				   // about above. It needs to be told
diff --git a/deal.II/examples/step-4/step-4.cc b/deal.II/examples/step-4/step-4.cc
index 5e0b2059d0..9e1be30a08 100644
--- a/deal.II/examples/step-4/step-4.cc
+++ b/deal.II/examples/step-4/step-4.cc
@@ -339,7 +339,7 @@ void LaplaceProblem<dim>::make_grid_and_dofs ()
 template <int dim>
 void LaplaceProblem<dim>::assemble_system () 
 {  
-  QGauss2<dim>  quadrature_formula;
+  QGauss<dim>  quadrature_formula(2);
 
 				   // We wanted to have a non-constant
 				   // right hand side, so we use an
diff --git a/deal.II/examples/step-5/step-5.cc b/deal.II/examples/step-5/step-5.cc
index de73e2a711..93d2697133 100644
--- a/deal.II/examples/step-5/step-5.cc
+++ b/deal.II/examples/step-5/step-5.cc
@@ -398,7 +398,7 @@ void LaplaceProblem<dim>::assemble_system ()
 				   // object will be used for this:
   const Coefficient<dim> coefficient;
 
-  QGauss2<dim>  quadrature_formula;
+  QGauss<dim>  quadrature_formula(2);
 
   FEValues<dim> fe_values (fe, quadrature_formula, 
 			   UpdateFlags(update_values    |
diff --git a/deal.II/examples/step-6/step-6.cc b/deal.II/examples/step-6/step-6.cc
index 9d10f5b0fb..dda25221d7 100644
--- a/deal.II/examples/step-6/step-6.cc
+++ b/deal.II/examples/step-6/step-6.cc
@@ -453,7 +453,7 @@ void LaplaceProblem<dim>::assemble_system ()
 				   // we use consist, a Gauss formula
 				   // with three points in each
 				   // direction is sufficient.
-  QGauss3<dim>  quadrature_formula;
+  QGauss<dim>  quadrature_formula(3);
 
 				   // The ``FEValues'' object
 				   // automatically adjusts the
@@ -735,7 +735,7 @@ void LaplaceProblem<dim>::refine_grid ()
 				   // integrates polynomials up to
 				   // order 5 exactly.)
   KellyErrorEstimator<dim>::estimate (dof_handler,
-				      QGauss3<dim-1>(),
+				      QGauss<dim-1>(3),
 				      neumann_boundary,
 				      solution,
 				      estimated_error_per_cell);
diff --git a/deal.II/examples/step-7/step-7.cc b/deal.II/examples/step-7/step-7.cc
index 00620db9c2..01f571c7b6 100644
--- a/deal.II/examples/step-7/step-7.cc
+++ b/deal.II/examples/step-7/step-7.cc
@@ -767,8 +767,8 @@ void LaplaceProblem<dim>::assemble_system ()
 				   // a quadrature rule for the faces:
 				   // it is simply a quadrature rule
 				   // for one dimension less!
-  QGauss3<dim>   quadrature_formula;
-  QGauss3<dim-1> face_quadrature_formula;
+  QGauss<dim>   quadrature_formula(3);
+  QGauss<dim-1> face_quadrature_formula(3);
 				   // For simpler use later on, we
 				   // alias the number of quadrature
 				   // points to local variables:
@@ -1114,7 +1114,7 @@ void LaplaceProblem<dim>::refine_grid ()
 
 	typename FunctionMap<dim>::type neumann_boundary;
 	KellyErrorEstimator<dim>::estimate (dof_handler,
-					    QGauss3<dim-1>(),
+					    QGauss<dim-1>(3),
 					    neumann_boundary,
 					    solution,
 					    estimated_error_per_cell);
@@ -1179,7 +1179,7 @@ void LaplaceProblem<dim>::process_solution (const unsigned int cycle)
 				     solution,
 				     Solution<dim>(),
 				     difference_per_cell,
-				     QGauss3<dim>(),
+				     QGauss<dim>(3),
 				     VectorTools::L2_norm);
 				   // Finally, we want to get the
 				   // global L2 norm. This can of
@@ -1198,7 +1198,7 @@ void LaplaceProblem<dim>::process_solution (const unsigned int cycle)
 				     solution,
 				     Solution<dim>(),
 				     difference_per_cell,
-				     QGauss3<dim>(),
+				     QGauss<dim>(3),
 				     VectorTools::H1_seminorm);
   const double H1_error = difference_per_cell.l2_norm();
 
diff --git a/deal.II/examples/step-8/step-8.cc b/deal.II/examples/step-8/step-8.cc
index 78b955bf5b..3ae01d2ef1 100644
--- a/deal.II/examples/step-8/step-8.cc
+++ b/deal.II/examples/step-8/step-8.cc
@@ -434,7 +434,7 @@ void ElasticProblem<dim>::assemble_system ()
 				   // formula does not need
 				   // modification since we still deal
 				   // with bilinear functions.
-  QGauss2<dim>  quadrature_formula;
+  QGauss<dim>  quadrature_formula(2);
 				   // Also, the ``FEValues'' objects
 				   // takes care of everything for us
 				   // (or better: it does not really
@@ -802,7 +802,7 @@ void ElasticProblem<dim>::refine_grid ()
 
   typename FunctionMap<dim>::type neumann_boundary;
   KellyErrorEstimator<dim>::estimate (dof_handler,
-				      QGauss2<dim-1>(),
+				      QGauss<dim-1>(2),
 				      neumann_boundary,
 				      solution,
 				      estimated_error_per_cell);
@@ -944,8 +944,9 @@ void ElasticProblem<dim>::run ()
 					   // twice before we first
 					   // solve on it. The reason
 					   // is the following: we use
-					   // the ``Gauss2''
-					   // quadrature formula for
+					   // the ``Gauss''
+					   // quadrature formula with
+					   // two points in each direction for
 					   // integration of the right
 					   // hand side; that means
 					   // that there are four
diff --git a/deal.II/examples/step-9/step-9.cc b/deal.II/examples/step-9/step-9.cc
index c0dff4e1cc..20441af60e 100644
--- a/deal.II/examples/step-9/step-9.cc
+++ b/deal.II/examples/step-9/step-9.cc
@@ -969,8 +969,8 @@ assemble_system_interval (const typename DoFHandler<dim>::active_cell_iterator &
 				   // elements, Gauss formulae with
 				   // two points in each space
 				   // direction are sufficient.
-  QGauss2<dim>   quadrature_formula;
-  QGauss2<dim-1> face_quadrature_formula;
+  QGauss<dim>   quadrature_formula(2);
+  QGauss<dim-1> face_quadrature_formula(2);
   
 				   // Finally, we need objects of type
 				   // ``FEValues'' and
diff --git a/deal.II/examples/step-10/step-10.cc b/deal.II/examples/step-10/step-10.cc
index 4bc0bf1e4d..0b02fc6c84 100644
--- a/deal.II/examples/step-10/step-10.cc
+++ b/deal.II/examples/step-10/step-10.cc
@@ -4,7 +4,7 @@
 /*    $Id$       */
 /*    Version: $Name$                                          */
 /*                                                                */
-/*    Copyright (C) 2001, 2002, 2003 by the deal.II authors */
+/*    Copyright (C) 2001, 2002, 2003, 2004 by the deal.II authors */
 /*                                                                */
 /*    This file is subject to QPL and may not be  distributed     */
 /*    without copyright and license information. Please refer     */
@@ -310,8 +310,8 @@ void compute_pi_by_area ()
 				   // For the numerical quadrature on
 				   // all cells we employ a quadrature
 				   // rule of sufficiently high
 				   // degree. We choose QGauss4 that
 				   // is of order 8, to be sure that
 				   // the errors due to numerical
 				   // quadrature are of higher order
 				   // than the order (maximal 6) that
@@ -329,7 +329,7 @@ void compute_pi_by_area ()
 				   // computations, but could as well
 				   // have used any quadrature formula
 				   // of like order instead.
-  const QGauss4<dim> quadrature;
+  const QGauss<dim> quadrature(4);
 
 				   // Now start by looping over
 				   // polynomial mapping degrees=1..4:
@@ -550,7 +550,7 @@ void compute_pi_by_perimeter ()
 				   // as we will integrate over
 				   // (boundary) lines rather than
 				   // over cells.
-  const QGauss4<dim-1> quadrature;
+  const QGauss<dim-1> quadrature(4);
 
 				   // We loop over all degrees, create
 				   // the Triangulation, the Boundary,
@@ -310,8 +310,8 @@ void compute_pi_by_area ()
 				   // all cells we employ a quadrature
 				   // rule of sufficiently high
-				   // degree. We choose QGauss4 that
-				   // is of order 8, to be sure that
+				   // degree. We choose QGauss that
+				   // is of order 8 (4 points), to be sure that
 				   // the errors due to numerical
 				   // quadrature are of higher order